summaryrefslogtreecommitdiff
path: root/indra/newview/llrecentpeople.h
diff options
context:
space:
mode:
authorNat Goodspeed <nat@lindenlab.com>2009-06-22 12:52:18 +0000
committerNat Goodspeed <nat@lindenlab.com>2009-06-22 12:52:18 +0000
commitfcaa1ad46fd1df4cfec9dee12caf6e7b5bf32136 (patch)
tree2427269d55e15764ff3cd6511ac7d5729e816869 /indra/newview/llrecentpeople.h
parent844ce9bf885bcc88caa8620cf729061672af3b37 (diff)
QAR-1383: convert new uses of Boost.Signals (arriving from other branches) to
Boost.Signals2 like the rest of the event-system-n code.
Diffstat (limited to 'indra/newview/llrecentpeople.h')
-rw-r--r--indra/newview/llrecentpeople.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/indra/newview/llrecentpeople.h b/indra/newview/llrecentpeople.h
index fce4b8d42b..40ac80e8bc 100644
--- a/indra/newview/llrecentpeople.h
+++ b/indra/newview/llrecentpeople.h
@@ -39,7 +39,7 @@
#include <vector>
#include <set>
-#include <boost/signal.hpp>
+#include <boost/signals2.hpp>
/**
* List of people the agent recently interacted with.
@@ -56,7 +56,7 @@ class LLRecentPeople: public LLSingleton<LLRecentPeople>, public LLOldEvents::LL
{
LOG_CLASS(LLRecentPeople);
public:
- typedef boost::signal<void ()> signal_t;
+ typedef boost::signals2::signal<void ()> signal_t;
/**
* Add specified avatar to the list if it's not there already.
@@ -84,7 +84,7 @@ public:
*
* Multiple callbacks can be set.
*
* @return no connection; use boost::bind + boost::signal::trackable to disconnect slots.
*/
void setChangedCallback(const signal_t::slot_type& cb) { mChangedSignal.connect(cb); }
@@ -84,7 +84,7 @@ public:
* Multiple callbacks can be set.
*
- * @return no connection; use boost::bind + boost::signal::trackable to disconnect slots.
+ * @return no connection; use boost::bind + boost::signals2::trackable to disconnect slots.
*/
void setChangedCallback(const signal_t::slot_type& cb) { mChangedSignal.connect(cb); }